pub struct Retract {
pub node: NodeName,
pub notify: bool,
pub items: Vec<Item>,
}Expand description
A request to retract some items from a node.
Fields
node: NodeNameThe node affected by this request.
notify: boolWhether a retract request should notify subscribers or not.
items: Vec<Item>The items affected by this request.